<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\UserRequest;
use App\Models\Crm;
use App\Models\Order;
use App\Models\User;
use Illuminate\Http\Request;

class UsersController extends Controller
{

    public function index()
    {

        $data = queryModels('User', [
            'type' => 'customer'
        ], [
            'perPage' => 20,
            'page' => 1
        ]);

        return view('admin.users.index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.users.create');

    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(UserRequest $request)
    {
        $data = User::create(array_merge($request->validated(), [
            'user_id' => auth()->id(),
        ]));

        if($data){
            Crm::create([
                'name'=> $request->first_name .''. $request->last_name,
                'email'=> $request->email,
                'phone'=> $request->phone,
            ]);
        }
        return redirect()->route('users.index')->with('success', 'User created successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $user = User::findOrFail($id);
        return view('admin.users.show', compact('user'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $user = User::findOrFail($id);
        return view('admin.users.edit', compact('user'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(UserRequest $request, $id)
    {
        $user = User::findOrFail($id);
        $user->update([
            'type'=>'customer',
            'first_name' => $request->input('first_name'),
            'last_name' => $request->input('last_name'),
            'email' => $request->input('email'),
            'phone' => $request->input('phone'),
            'gender' => $request->input('gender'),
            'password' => $request->input('password') ? bcrypt($request->input('password')) : $user->password,
        ]);
        return redirect()->route('users.index')->with('success', 'User updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $checkOrders = Order::where('customer_id',\request()->id)->first();
        if ($checkOrders){
            return redirect()->route('admin_users.index')->with('error', 'This user cannot be deleted because he has requests.');
        }
        $user = User::findOrFail(\request()->id);
        $user->delete();
        return redirect()->route('admin_users.index')->with('success', 'User deleted successfully.');
   
    }

    public function updateUsersStatus(Request $request)
    {

        $brand = User::find($request->id);
        if (!$brand) {
            return response()->json(['success' => false, 'message' => 'العلامة التجارية غير موجودة']);
        }
        $brand->is_active = $request->active;
        $brand->save();

        return response()->json(['success' => true, 'message' => 'تم تحديث الحالة بنجاح']);
    }
}
